import React from 'react';
import { useEffect } from 'react';
import ReactDOM from 'react-dom/client';
import './index.css';
import { IgrFinancialChart } from 'igniteui-react-charts';
import { IgrFinancialChartModule } from 'igniteui-react-charts';
import { IgrLegend } from 'igniteui-react-charts';
import { IgrLegendModule } from 'igniteui-react-charts';
import StocksHistory from './StocksHistory';

IgrFinancialChartModule.register();
IgrLegendModule.register();

export default class ChartPage extends React.Component<any, any> {
    public data: any[];
    public chart: IgrFinancialChart;
    public legend: IgrLegend;

    constructor(props: any) {
        super(props);

        this.onChartRef = this.onChartRef.bind(this);
        this.onLegendRef = this.onLegendRef.bind(this);
        this.state = { chartType: "Auto", data: [] }
        this.initData();
    }

    public render(): JSX.Element {
        return (            
            <div>
                <IgrFinancialChart
                    ref={this.onChartRef}
                    width="100%"
                    height="800px"
                    isToolbarVisible={true}
                    chartType="Candle"
                    chartTitle="Crypto Trades"
                    titleAlignment="Left"
                    titleLeftMargin="25"
                    titleTopMargin="10"
                    titleBottomMargin="10"
                    subtitle="Binance - CryptoCoin Price, Currency in USD"
                    subtitleAlignment="Left"
                    subtitleLeftMargin="25"
                    subtitleTopMargin="5"
                    subtitleBottomMargin="10"
                    yAxisMode="Numeric"
                    zoomSliderType="None"
                    dataSource={this.data} />
            </div>            
        );
    }

    public onChartRef(chart: IgrFinancialChart) {
        if (!chart) { return; }

        this.chart = chart;
        if (this.legend) {
            this.chart.legend = this.legend;
        }
    }

    public onLegendRef(legend: IgrLegend) {
        if (!legend) { return; }

        this.legend = legend;
        if (this.chart) {
            this.chart.legend = this.legend;
        }
    }

    public initData() {

        const today = new Date();
        // const endOfDay = new Date(today.getFullYear(), today.getMonth(), today.getDate() + 1).getTime();
        const todayMidnight = new Date(today.getFullYear(), today.getMonth(), today.getDate());
        console.log(today.getTime());

        fetch(`https://api.binance.com/api/v3/uiKlines?symbol=BTCUSDT&interval=1m&startTime=${todayMidnight.getTime()}&endTime=${today.getTime()}&limit=1000`)
            .then(res => res.json())
            .then(data => {

                let newdata = [];

                data.forEach(item => {

                    newdata = [...newdata, {
                        date: new Date(item[0]),
                        open: parseFloat(item[1]),
                        high: parseFloat(item[2]),
                        low: parseFloat(item[3]),
                        close: parseFloat(item[4]),
                        volume: parseFloat(item[5])
                    }]


                });

                // console.log("Historical Data is : ", newdata);

                //setChartData((chartData) => [...chartData, newdata])
                this.data = data;
            });

        const ws = new WebSocket(`wss://stream.binance.com:9443/ws/btcusdt@kline_1s`);

        ws.onmessage = (e) => {
            const dataJson = JSON.parse(e.data);
            // console.log("DataJson is : ", dataJson);

            const newdata = {
                date: new Date(dataJson.k.t),
                open: parseFloat(dataJson.k.o),
                high: parseFloat(dataJson.k.h),
                low: parseFloat(dataJson.k.l),
                close: parseFloat(dataJson.k.c),
                volume: parseFloat(dataJson.k.v)
            }

            // console.log(newdata);
            // console.log(chartRef.current.dataSource);            
            this.data.push(newdata);
            this.chart.notifyInsertItem(this.data, this.data.length - 1, newdata);
        }
    }
}

// rendering above class to the React DOM
const root = ReactDOM.createRoot(document.getElementById('root'));
root.render(<ChartPage/>);
